@@ -3,6 +3,6 @@ from enum import Enum
 
 def calculate(enum: Enum):
     def decorate(ref):
-        setattr(ref, 'enum', enum)
+        setattr(ref, 'calculation', enum)
         return ref
     return decorate
